Module key_provider

Module key_provider 

Key provider trait for SecureContent encryption/decryption

This module defines the interface for providing customer keys for decryption during parsing and encryption during writing.

Traits

KeyProvider
Trait for providing encryption/decryption keys for SecureContent