Object

Struct Object 

pub struct Object {
    pub id: usize,
    pub name: Option<String>,
    pub object_type: ObjectType,
    pub mesh: Option<Mesh>,
    pub displacement_mesh: Option<DisplacementMesh>,
    pub pid: Option<usize>,
    pub pindex: Option<usize>,
    pub basematerialid: Option<usize>,
    pub slicestackid: Option<usize>,
    pub production: Option<ProductionInfo>,
    pub boolean_shape: Option<BooleanShape>,
    pub components: Vec<Component>,
    /* private fields */
}
A 3D object that can be a mesh or reference other objects

Fields

id: usize

Object ID

name: Option<String>

Object name (optional)

object_type: ObjectType

Type of object

mesh: Option<Mesh>

Optional mesh data

displacement_mesh: Option<DisplacementMesh>

Optional displacement mesh data (Displacement extension) An object can have either a regular mesh OR a displacement mesh, not both

pid: Option<usize>

Optional material ID (property ID)

pindex: Option<usize>

Optional material index (property index) - used with pid to select from color groups

basematerialid: Option<usize>

Optional base material ID reference (materials extension)

slicestackid: Option<usize>

Optional slice stack ID (slice extension)

production: Option<ProductionInfo>

Production extension information (UUID, path)

boolean_shape: Option<BooleanShape>

Boolean shape definition (Boolean Operations extension)

components: Vec<Component>

Components that reference other objects (assemblies)

Implementations

Source

impl Object

pub fn new(id: usize) -> Self

Create a new object